@@ -15,11 +15,6 @@ Usage (module):
     import jc
     result = jc.parse('airport', airport_command_output)
 
-    or
-
-    import jc.parsers.airport
-    result = jc.parsers.airport.parse(airport_command_output)
-
 Schema:
 
     {
@@ -85,7 +80,7 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.4'
+    version = '1.5'
     description = '`airport -I` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -108,9 +103,9 @@ def _process(proc_data):
 
         Dictionary. Structured data to conform to the schema.
     """
-    # integer changes
-    int_list = ['agrctlrssi', 'agrextrssi', 'agrctlnoise', 'agrextnoise',
-                'lasttxrate', 'maxrate', 'lastassocstatus', 'mcs']
+    int_list = {'agrctlrssi', 'agrextrssi', 'agrctlnoise', 'agrextnoise',
+                'lasttxrate', 'maxrate', 'lastassocstatus', 'mcs'}
+
     for key in proc_data:
         if key in int_list:
             proc_data[key] = jc.utils.convert_to_int(proc_data[key])
