@@ -14,18 +14,13 @@ time of the system the parser is run on)
 
 Usage (cli):
 
-    C:> dir | jc --dir
+    C:\> dir | jc --dir
 
 Usage (module):
 
     import jc
     result = jc.parse('dir', dir_command_output)
 
-    or
-
-    import jc.parsers.dir
-    result = jc.parsers.dir.parse(dir_command_output)
-
 Schema:
 
     [
@@ -42,7 +37,7 @@ Schema:
 
 Examples:
 
-    C:> dir | jc --dir -p
+    C:\> dir | jc --dir -p
     [
       {
         "date": "03/24/2021",
@@ -83,7 +78,7 @@ Examples:
       ...
     ]
 
-    C:> dir | jc --dir -p -r
+    C:\> dir | jc --dir -p -r
     [
       {
         "date": "03/24/2021",
@@ -126,7 +121,7 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.5'
+    version = '1.6'
     description = '`dir` command parser'
     author = 'Rasheed Elsaleh'
     author_email = 'rasheed@rebelliondefense.com'
@@ -148,6 +143,8 @@ def _process(proc_data):
 
         List of Dictionaries. Structured data to conform to the schema.
     """
+    int_list = {'size'}
+
     for entry in proc_data:
         # add timestamps
         if 'date' in entry and 'time' in entry:
@@ -156,7 +153,6 @@ def _process(proc_data):
             entry['epoch'] = timestamp.naive
 
         # add ints
-        int_list = ["size"]
         for key in entry:
             if key in int_list:
                 entry[key] = jc.utils.convert_to_int(entry[key])
