@@ -13,11 +13,6 @@ Usage (module):
     import jc
     result = jc.parse('dmidecode', dmidecode_command_output)
 
-    or
-
-    import jc.parsers.dmidecode
-    result = jc.parsers.dmidecode.parse(dmidecode_command_output)
-
 Schema:
 
     [
@@ -130,7 +125,7 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.4'
+    version = '1.5'
     description = '`dmidecode` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -153,8 +148,9 @@ def _process(proc_data):
 
         List of Dictionaries. Structured data to conform to the schema.
     """
+    int_list = {'type', 'bytes'}
+
     for entry in proc_data:
-        int_list = ['type', 'bytes']
         for key in entry:
             if key in int_list:
                 entry[key] = jc.utils.convert_to_int(entry[key])
