@@ -13,11 +13,6 @@ Usage (module):
     import jc
     result = jc.parse('free', free_command_output)
 
-    or
-
-    import jc.parsers.free
-    result = jc.parsers.free.parse(free_command_output)
-
 Schema:
 
     [
@@ -78,7 +73,7 @@ import jc.parsers.universal
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.5'
+    version = '1.6'
     description = '`free` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -101,9 +96,9 @@ def _process(proc_data):
 
         List of Dictionaries. Structured data to conform to the schema.
     """
+    int_list = {'total', 'used', 'free', 'shared', 'buff_cache', 'available'}
 
     for entry in proc_data:
-        int_list = ['total', 'used', 'free', 'shared', 'buff_cache', 'available']
         for key in entry:
             if key in int_list:
                 entry[key] = jc.utils.convert_to_int(entry[key])
