@@ -13,11 +13,6 @@ Usage (module):
     import jc
     result = jc.parse('systemctl_lj', systemctl_lj_command_output)
 
-    or
-
-    import jc.parsers.systemctl_lj
-    result = jc.parsers.systemctl_lj.parse(systemctl_lj_command_output)
-
 Schema:
 
     [
@@ -80,7 +75,7 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.6'
+    version = '1.7'
     description = '`systemctl list-jobs` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -103,8 +98,9 @@ def _process(proc_data):
 
         List of Dictionaries. Structured data to conform to the schema.
     """
+    int_list = {'job'}
+
     for entry in proc_data:
-        int_list = ['job']
         for key in entry:
             if key in int_list:
                 entry[key] = jc.utils.convert_to_int(entry[key])
