@@ -2,12 +2,12 @@
 
 Supports `traceroute` and `traceroute6` output.
 
-Note: On some operating systems you will need to redirect `STDERR` to
-      `STDOUT` for destination info since the header line is sent to
-      `STDERR`. A warning message will be printed to `STDERR` if the
-      header row is not found.
-
-      e.g. `$ traceroute 8.8.8.8 2>&1 | jc --traceroute`
+> Note: On some operating systems you will need to redirect `STDERR` to
+> `STDOUT` for destination info since the header line is sent to
+> `STDERR`. A warning message will be printed to `STDERR` if the
+> header row is not found.
+>
+> e.g. `$ traceroute 8.8.8.8 2>&1 | jc --traceroute`
 
 Usage (cli):
 
@@ -22,11 +22,6 @@ Usage (module):
     import jc
     result = jc.parse('traceroute', traceroute_command_output)
 
-    or
-
-    import jc.parsers.traceroute
-    result = jc.parsers.traceroute.parse(traceroute_command_output)
-
 Schema:
 
     {
@@ -127,7 +122,7 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.4'
+    version = '1.5'
     description = '`traceroute` and `traceroute6` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -336,8 +331,8 @@ def _process(proc_data):
 
         Dictionary. Structured to conform to the schema.
     """
-    int_list = ['hop', 'asn']
-    float_list = ['rtt']
+    int_list = {'hop', 'asn'}
+    float_list = {'rtt'}
 
     if 'hops' in proc_data:
         for entry in proc_data['hops']:
