@@ -1,7 +1,7 @@
 """jc - JSON Convert `vmstat` command output streaming parser
 
 > This streaming parser outputs JSON Lines (cli) or returns an Iterable of
-  Dictionaries (module)
+> Dictionaries (module)
 
 Options supported: `-a`, `-w`, `-d`, `-t`
 
@@ -16,11 +16,11 @@ Usage (cli):
     $ vmstat | jc --vmstat-s
 
 > Note: When piping `jc` converted `vmstat` output to other processes it may
-  appear the output is hanging due to the OS pipe buffers. This is because
-  `vmstat` output is too small to quickly fill up the buffer. Use the `-u`
-  option to unbuffer the `jc` output if you would like immediate output. See
-  the [readme](https://github.com/kellyjonbrazil/jc/tree/master#unbuffering-output)
-  for more information.
+> appear the output is hanging due to the OS pipe buffers. This is because
+> `vmstat` output is too small to quickly fill up the buffer. Use the `-u`
+> option to unbuffer the `jc` output if you would like immediate output. See
+> the [readme](https://github.com/kellyjonbrazil/jc/tree/master#unbuffering-output)
+> for more information.
 
 Usage (module):
 
@@ -70,9 +70,9 @@ Schema:
 
       # below object only exists if using -qq or ignore_exceptions=True
       "_jc_meta": {
-        "success":                        boolean,  # [2]
-        "error":                          string,   # [3]
-        "line":                           string    # [3]
+        "success":                        boolean,     # [2]
+        "error":                          string,      # [3]
+        "line":                           string       # [3]
       }
     }
 
@@ -100,7 +100,7 @@ from jc.exceptions import ParseError
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.0'
+    version = '1.1'
     description = '`vmstat` command streaming parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -123,13 +123,13 @@ def _process(proc_data):
 
         Dictionary. Structured data to conform to the schema.
     """
-    int_list = [
+    int_list = {
         'runnable_procs', 'uninterruptible_sleeping_procs', 'virtual_mem_used', 'free_mem',
         'buffer_mem', 'cache_mem', 'inactive_mem', 'active_mem', 'swap_in', 'swap_out', 'blocks_in',
         'blocks_out', 'interrupts', 'context_switches', 'user_time', 'system_time', 'idle_time',
         'io_wait_time', 'stolen_time', 'total_reads', 'merged_reads', 'sectors_read', 'reading_ms',
         'total_writes', 'merged_writes', 'sectors_written', 'writing_ms', 'current_io', 'io_seconds'
-    ]
+    }
 
     for key in proc_data:
         if key in int_list:
